Simply, map a sequence of amino acids to the corresponding counts of atoms.

Installation
------------

```batch
pip3 install aa2atom
```

Usage
-----
```python
from aa2atom import aa2atom

aa2atom("MDYSNFGNSASKKFQDDTLNRVRKEHEEA")
aa2atom("SASKKF")
aa2atom("AREDRSSQIHIENESTEDILKILSSSFHN")
```

Terminal usage
```batch
aa2atom MDYSNFGNSASKKFQDDTLNRVRKEHEEA
aa2atom SASKKF
aa2atom AREDRSSQIHIENESTEDILKILSSSFHN
```